@@ -637,7 +637,7 @@ mod tests {
 
             // Sometimes the previous assert doesn't trigger, so we put this one
             // here as a safety measure. Do not remove it!!
-            assert!(false);
+            panic!("Example failed");
         }
 
         if !diff_files.is_empty() {
